change the proj name back to "tizenpkg"
authorJF Ding <jian-feng.ding@intel.com>
Mon, 5 Dec 2011 03:56:44 +0000 (11:56 +0800)
committerJF Ding <jian-feng.ding@intel.com>
Mon, 5 Dec 2011 03:56:44 +0000 (11:56 +0800)
23 files changed:
Makefile
README.rst
data/build.sh
data/packaging.sh
distfiles/debian/control
distfiles/debian/copyright
distfiles/debian/rules
distfiles/tizenpkg.conf [moved from distfiles/pkghelper.conf with 100% similarity]
distfiles/tizenpkg.dsc [moved from distfiles/pkghelper.dsc with 82% similarity]
distfiles/tizenpkg.spec [moved from distfiles/pkghelper.spec with 96% similarity]
distfiles/tizenpkg.yaml [moved from distfiles/pkghelper.yaml with 96% similarity]
setup.py
tizenpkg/__init__.py [moved from pkghelper/__init__.py with 96% similarity]
tizenpkg/cmd_build.py [moved from pkghelper/cmd_build.py with 100% similarity]
tizenpkg/cmdln.py [moved from pkghelper/cmdln.py with 100% similarity]
tizenpkg/conf.py [moved from pkghelper/conf.py with 99% similarity]
tizenpkg/errors.py [moved from pkghelper/errors.py with 100% similarity]
tizenpkg/git.py [moved from pkghelper/git.py with 100% similarity]
tizenpkg/msger.py [moved from pkghelper/msger.py with 100% similarity]
tizenpkg/runner.py [moved from pkghelper/runner.py with 100% similarity]
tizenpkg/srcserver.py [moved from pkghelper/srcserver.py with 100% similarity]
tizenpkg/utils.py [moved from pkghelper/utils.py with 97% similarity]
tools/tizenpkg [moved from tools/pkghelper with 85% similarity]

index 0a22ac7..c138cdd 100644 (file)
--- a/Makefile
+++ b/Makefile
@@ -18,12 +18,12 @@ tag:
        git tag $(VERSION)
 
 dist-bz2:
-       git archive --format=tar --prefix=pkghelper-$(TAGVER)/ $(TAG) | \
-               bzip2  > pkghelper-$(TAGVER).tar.bz2
+       git archive --format=tar --prefix=tizenpkg-$(TAGVER)/ $(TAG) | \
+               bzip2 > tizenpkg-$(TAGVER).tar.bz2
 
 dist-gz:
-       git archive --format=tar --prefix=pkghelper-$(TAGVER)/ $(TAG) | \
-               gzip  > pkghelper-$(TAGVER).tar.gz
+       git archive --format=tar --prefix=tizenpkg-$(TAGVER)/ $(TAG) | \
+               gzip > tizenpkg-$(TAGVER).tar.gz
 
 install: all
        python setup.py install --prefix=${PREFIX}
index 0fbd256..1db3181 100644 (file)
@@ -1,6 +1,6 @@
-=========
-pkghelper
-=========
+========
+tizenpkg
+========
 ---------------------------------------------------
 The command line tools for Tizen package developers
 ---------------------------------------------------
index 3098755..546afcd 100644 (file)
@@ -1,6 +1,6 @@
 #!/bin/bash
 USAGE="usage:
-    pkghelper build [target OBS project]
+    tizenpkg build [target OBS project]
 
 Build package at remote build server, the default target OBS project
 is home:<user_id>:branches:Trunk
@@ -50,11 +50,11 @@ fi
 # tar the local changes
 tar jcf package.tar.bz2 `git ls-files`
 
-# get user name/passwd from pkghelper.conf
-user=$(pkghelper cfg user)
-passwd=$(pkghelper cfg passwd)
-HUDSON_SERVER=$(pkghelper cfg src_server)
-passwdx=$(pkghelper cfg passwdx)
+# get user name/passwd from tizenpkg.conf
+user=$(tizenpkg cfg user)
+passwd=$(tizenpkg cfg passwd)
+HUDSON_SERVER=$(tizenpkg cfg src_server)
+passwdx=$(tizenpkg cfg passwdx)
 echo "Submiting your changes to build server"
 
 ret_string=$(curl -i -s -u$user:$passwd -Fname=package.tar.bz2 -Ffile0=@package.tar.bz2 -Fjson='{"parameter": [{"name": "package.tar.bz2", "file": "file0"},{"name":"pkg", "value":"'$prj_name'"},{"name":"parameters","value":"obsproject='$target_obsproject';passwdx='$passwdx'"}]}' -FSubmit=Build "$HUDSON_SERVER/job/build/build")
@@ -63,7 +63,7 @@ echo $ret_string|grep '302' > /dev/null
 
 if [ $? != 0 ]; then
     echo $ret_string
-    die "Server Error, please check your pkghelper configuration"
+    die "Server Error, please check your tizenpkg configuration"
 fi
 
 sleep 2
index aa673dd..f3ed08b 100644 (file)
@@ -1,7 +1,7 @@
 #!/bin/bash
 
 USAGE="usage:
-    pkghelper packaging [git tag/commit id] [-s] [-t tag] [-f spec file]
+    tizenpkg packaging [git tag/commit id] [-s] [-t tag] [-f spec file]
 
 Packaging master branch, convert the files to release branch
 from the given tag or commit id, by default it's the HEAD.
@@ -209,7 +209,7 @@ get_srctar_md5sum()
     echo $string|grep '302' > /dev/null
     if [ $? != 0 ]; then
         echo $string
-        die "Server Error, please check your pkghelper configuration"
+        die "Server Error, please check your tizenpkg configuration"
     fi
     
     last_id=`curl -s -u$user:$passwd "$HUDSON_SERVER/job/srctar_md5sum/lastBuild/buildNumber"`
@@ -315,9 +315,9 @@ if [ -z "$tag" ];then
     tag=$(git describe $git_obj --abbrev=0 --tags)
 fi
 
-user=$(pkghelper cfg user)
-passwd=$(pkghelper cfg passwd)
-HUDSON_SERVER=$(pkghelper cfg src_server)
+user=$(tizenpkg cfg user)
+passwd=$(tizenpkg cfg passwd)
+HUDSON_SERVER=$(tizenpkg cfg src_server)
 
 git_url=`git config remote.origin.url`
 echo $git_url|grep ^ssh  > /dev/null
index 8f2aacd..6ad04b9 100644 (file)
@@ -1,4 +1,4 @@
-Source: pkghelper
+Source: tizenpkg
 Section: devel
 Priority: extra
 Maintainer: Jian-feng Ding <jian-feng.ding@intel.com>
@@ -6,7 +6,7 @@ Build-Depends: debhelper (>= 7.0.15), python-dev
 Standards-Version: 3.8.0
 Homepage: http://www.tizen.org
 
-Package: pkghelper
+Package: tizenpkg
 Architecture: all
 Depends: ${misc:Depends}, ${python:Depends},
  git-core,
index 996836d..e116bcd 100644 (file)
@@ -14,7 +14,7 @@ Copyright:
 
     Copyright (C) 2011 Intel Inc.
 
-Copyright for pkghelper/cmdln.py:
+Copyright for tizenpkg/cmdln.py:
 
     Copyright (C) 2002-2005 ActiveState Corp.
     Copyright (C) Trent Mick <trentm@activestate.com>
index 18c017f..de8fc68 100755 (executable)
@@ -20,11 +20,11 @@ install: build
        dh_clean -k
        dh_installdirs
        # Installing package
-       mkdir -p $(CURDIR)/debian/pkghelper /usr/bin
-       #make DESTDIR=$(CURDIR)/debian/pkghelper installman
-       #make DESTDIR=$(CURDIR)/debian/pkghelper installconf
-       #make DESTDIR=$(CURDIR)/debian/pkghelper installsymlinks
-       python setup.py install --root=$(CURDIR)/debian/pkghelper --prefix=/usr --install-layout=deb
+       mkdir -p $(CURDIR)/debian/tizenpkg /usr/bin
+       #make DESTDIR=$(CURDIR)/debian/tizenpkg installman
+       #make DESTDIR=$(CURDIR)/debian/tizenpkg installconf
+       #make DESTDIR=$(CURDIR)/debian/tizenpkg installsymlinks
+       python setup.py install --root=$(CURDIR)/debian/tizenpkg --prefix=/usr --install-layout=deb
 
 binary-indep: build install
        dh_testdir
similarity index 82%
rename from distfiles/pkghelper.dsc
rename to distfiles/tizenpkg.dsc
index fda008a..3eedeba 100644 (file)
@@ -1,7 +1,7 @@
 Format: 1.0
-Source: pkghelper
+Source: tizenpkg
 Version: 0.1
-Binary: pkghelper
+Binary: tizenpkg
 Maintainer: Jian-feng Ding <jian-feng.ding@intel.com>
 Architecture: all
 Standards-Version: 3.7.1
similarity index 96%
rename from distfiles/pkghelper.spec
rename to distfiles/tizenpkg.spec
index f2e0748..fca94f0 100644 (file)
@@ -6,7 +6,7 @@
 # << macros
 
 %{!?python_sitelib: %define python_sitelib %(%{__python} -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
-Name:       pkghelper
+Name:       tizenpkg
 Summary:    The command line tools for Tizen package developers
 Version:    0.1
 Release:    1
@@ -15,7 +15,7 @@ License:    GPLv2
 BuildArch:  noarch
 URL:        http://www.tizen.org
 Source0:    %{name}-%{version}.tar.gz
-Source100:  pkghelper.yaml
+Source100:  tizenpkg.yaml
 Requires:   python >= 2.5
 Requires:   git-core
 Requires:   curl
similarity index 96%
rename from distfiles/pkghelper.yaml
rename to distfiles/tizenpkg.yaml
index b7fa26e..ee04947 100644 (file)
@@ -1,4 +1,4 @@
-Name: pkghelper
+Name: tizenpkg
 Summary: The command line tools for Tizen package developers
 Version: 0.1
 Release: 1
index 5b78c82..f8e4e79 100644 (file)
--- a/setup.py
+++ b/setup.py
@@ -9,7 +9,7 @@ try:
 except ImportError:
     pass
 
-MOD_NAME = 'pkghelper'
+MOD_NAME = 'tizenpkg'
 
 version_path = 'VERSION'
 if not os.path.isfile(version_path):
@@ -43,14 +43,14 @@ if sys.version_info[:2] > (2, 5):
         except:
             pass
 
-setup(name='pkghelper',
+setup(name='tizenpkg',
       version = version,
       description='The command line tools for Tizen package developers',
       author='Jian-feng Ding, Huaxu Wan',
       author_email='jian-feng.ding@intel.com, huaxu.wan@intel.com',
       url='http://git.tizen.org/',
-      scripts=['tools/pkghelper'],
-      packages=['pkghelper'],
-      data_files = [('/usr/share/pkghelper', glob.glob('data/*'))],
+      scripts=['tools/tizenpkg'],
+      packages=['tizenpkg'],
+      data_files = [('/usr/share/tizenpkg', glob.glob('data/*'))],
      )
 
similarity index 96%
rename from pkghelper/__init__.py
rename to tizenpkg/__init__.py
index 58f68a1..4e3bbfa 100644 (file)
@@ -17,6 +17,6 @@
 # Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
 """
-module for pkghelper tool
+module for tizenpkg tool
 """
 
similarity index 100%
rename from pkghelper/cmd_build.py
rename to tizenpkg/cmd_build.py
similarity index 100%
rename from pkghelper/cmdln.py
rename to tizenpkg/cmdln.py
similarity index 99%
rename from pkghelper/conf.py
rename to tizenpkg/conf.py
index cc5fae9..5f1e3ac 100644 (file)
@@ -242,7 +242,7 @@ passwdx = $passwdx
 
         if not fpath:
             # use the default path
-            fpath = os.path.expanduser('~/.pkghelper.conf')
+            fpath = os.path.expanduser('~/.tizenpkg.conf')
 
         if not os.path.exists(fpath):
             if not self._new_conf(fpath):
similarity index 100%
rename from pkghelper/errors.py
rename to tizenpkg/errors.py
similarity index 100%
rename from pkghelper/git.py
rename to tizenpkg/git.py
similarity index 100%
rename from pkghelper/msger.py
rename to tizenpkg/msger.py
similarity index 100%
rename from pkghelper/runner.py
rename to tizenpkg/runner.py
similarity index 100%
rename from pkghelper/srcserver.py
rename to tizenpkg/srcserver.py
similarity index 97%
rename from pkghelper/utils.py
rename to tizenpkg/utils.py
index ac1888e..662e49e 100644 (file)
@@ -48,4 +48,4 @@ def strip_end(text, suffix):
 
 def get_share_dir():
     # TODO need to be better
-    return '/usr/share/pkghelper/'
+    return '/usr/share/tizenpkg/'
similarity index 85%
rename from tools/pkghelper
rename to tools/tizenpkg
index 15b5659..c274da4 100755 (executable)
@@ -20,9 +20,9 @@ import os, sys
 import io
 import ConfigParser
 
-from pkghelper.__version__ import VERSION
-from pkghelper import msger, cmdln, errors, utils, runner
-from pkghelper.conf import configmgr
+from tizenpkg.__version__ import VERSION
+from tizenpkg import msger, cmdln, errors, utils, runner
+from tizenpkg.conf import configmgr
 
 def _fall_to_shell(cmdname):
     def raw_wrapper(f):
@@ -35,7 +35,7 @@ def _fall_to_shell(cmdname):
             runner.embed(['bash', shpath] + list(argv)[1:])
         return _run_embed_sh
 
-    cmdmod = 'pkghelper.cmd_' + cmdname
+    cmdmod = 'tizenpkg.cmd_' + cmdname
     try:
         __import__(cmdmod)
         return raw_wrapper
@@ -44,17 +44,17 @@ def _fall_to_shell(cmdname):
 
 class TizenPkg(cmdln.Cmdln):
     """
-    Usage: pkghelper [GLOBAL-OPTS] SUBCOMMAND [OPTS] [ARGS...]
+    Usage: tizenpkg [GLOBAL-OPTS] SUBCOMMAND [OPTS] [ARGS...]
 
pkghelper - the command line tool for Tizen package developers
Try 'pkghelper help SUBCOMAND' for help on a specific subcommand.
 
     ${command_list}
     global ${option_list}
     ${help_list}
     """
 
-    name = 'pkghelper'
+    name = 'tizenpkg'
     version = VERSION
 
     def get_optparser(self):
@@ -80,12 +80,12 @@ class TizenPkg(cmdln.Cmdln):
         """${cmd_name}: test building for current pkg
 
         Usage:
-            pkghelper build [OBS_project]
+            tizenpkg build [OBS_project]
 
         ${cmd_option_list}
         """
 
-        from pkghelper import cmd_build as cmd
+        from tizenpkg import cmd_build as cmd
         cmd.do(opts, args)
 
     @cmdln.alias("pk")
@@ -96,12 +96,12 @@ class TizenPkg(cmdln.Cmdln):
         """${cmd_name}: prepare packaging files for current pkg
 
         Usage:
-            pkghelper packaging
+            tizenpkg packaging
 
         ${cmd_option_list}
         """
 
-        from pkghelper import cmd_packaging as cmd
+        from tizenpkg import cmd_packaging as cmd
         cmd.do(opts, args)
 
     @_fall_to_shell('import')
@@ -109,12 +109,12 @@ class TizenPkg(cmdln.Cmdln):
         """${cmd_name}: import new tarballs for current pkg
 
         Usage:
-            pkghelper import
+            tizenpkg import
 
         ${cmd_option_list}
         """
 
-        from pkghelper import cmd_import as cmd
+        from tizenpkg import cmd_import as cmd
         cmd.do(opts, args)
 
     @cmdln.alias("cfg")
@@ -124,7 +124,7 @@ class TizenPkg(cmdln.Cmdln):
         """${cmd_name}: query values of config file
 
         Usage:
-            pkghelper getconfig <opt1> [<opt2> ...]
+            tizenpkg getconfig <opt1> [<opt2> ...]
 
         ${cmd_option_list}
         """
@@ -44,17 +44,17 @@ def _fall_to_shell(cmdname):
 
-    pkghelper - the command line tool for Tizen package developers
-    Try 'pkghelper help SUBCOMAND' for help on a specific subcommand.
+    tizenpkg - the command line tool for Tizen package developers
+    Try 'tizenpkg help SUBCOMAND' for help on a specific subcommand.
 
     ${command_list}